#
# spec file for package texlab
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           texlab
Version:        5.20.0
Release:        1.2
Summary:        Implementation of the Language Server Protocol for LaTeX
License:        ( 0BSD OR MIT OR Apache-2.0 ) AND ( Apache-2.0 OR BSL-1.0 ) AND ( Apache-2.0 OR MIT ) AND ( Apache-2.0 OR Apache-2.0 OR MIT ) AND ( CC0-1.0 OR Artistic-2.0 ) AND ( MIT OR Apache-2.0 OR Zlib ) AND ( MIT OR Zlib OR Apache-2.0 ) AND ( Unlicense OR MIT ) AND ( Zlib OR Apache-2.0 OR MIT ) AND Apache-2.0 AND BSD-3-Clause AND GPL-3.0 AND GPL-3.0+ AND ISC AND MIT AND MPL-2.0 AND MPL-2.0+ AND GPL-3.0
Group:          Productivity/Publishing/TeX/Utilities
URL:            https://github.com/latex-lsp/texlab
Source0:        %{url}/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  cargo
BuildRequires:  cargo-packaging
BuildRequires:  zstd
ExclusiveArch:  %{rust_tier1_arches}

%description
Cross-platform implementation of the Language Server Protocol providing rich
cross-editing support for the LaTeX typesetting system.
The server may be used with any editor that implements the Language Server Protocol.

%prep
%autosetup -a1

%build
%{cargo_build} --all-features --frozen --locked

%install
mkdir -p %{buildroot}%{_bindir}
install -m 0755 %{_builddir}/%{name}-%{version}/target/release/%{name} %{buildroot}%{_bindir}/%{name}

%check
%{cargo_test} --all-features --frozen --locked

%files
%{_bindir}/texlab
%license LICENSE
%doc README.md CHANGELOG.md

%changelog
* Thu Oct 24 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update to version 5.20.0:
  * Add texlab.inlayHints.maxLength setting to allow limiting inlay hint text length
  * Allow suppressing diagnostics using %% texlab: ignore magic comments
  * Fix enabling texlab.build.useFileList setting
  * Make "Goto Definition" work correctly with starred commands
  * Add texlab.build.useFileList setting to allow controlling whether to use the .fls files
  * Disable using .fls files for project detection by default
  * Parse .fls files to make the project detection more reliable
  * Fix parsing commands with unicode characters inside BibTeX entries
  * Improve detection of included files when non-ASCII characters are used
  * Fix resolving includes starting from files included using \subimport
* Mon Jun 24 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Update to version 5.17.0:
  * Add label commands from zref and zref-clever to the list of default label commands
  * Add texlab.experimental.labelDefinitionPrefixes and texlab.experimental.labelReferencePrefixes options
* Wed May 29 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 5.16.1. Changes since then:
  * Don't treat `\label{}` and `\ref{}` with macro parameter as label commands
  * Fix parsing `latexmkrc` for `latexmk` versions older than `v4.8.4`
  * Remove unused `texlab.rootDirectory` setting from documentation
  * Add `texlab.experimental.labelDefinitionCommands` setting to customize the list of `\label`-like commands
  * Extend list of commands treated as command definitions and environment definitions
  * Allow the server to trigger the forward search in an editor-agnostic way:
    Running `texlab inverse-search --input <FILE> --line <LINE>` will open the specified document in the editor if the client supports it
  * Fix detection of log dir when using `latexmkrc` (use `$aux_dir` instead of `$out_dir`)
  * Fix extracting `$aux_dir` and `$out_dir` from `latexmkrc`
  * Add support for extracting `$aux_dir` and `$out_dir` from `latexmk >= v4.85`
  * Improve log file change detection under Windows
  * Cleanup diagnostics of deleted files
  * Let `\declaretheorem` accept a list of environment names instead of just a single name
  * Use configured directories if not set explicitly by `latexmkrc` file
  * Replace tilde (`~`), environment variables, `${userHome}`, `${workspaceFolder}` in options
  * Replace tidle (`~`) and environment variables in `\include`-like commands
  * Add "Go To Definition" support for user-defined commands with `\def` and `\let`
  * Add "Find all References" for commands
  * Support more macros for defining commands
  * Avoid panicking when malformed URIs are sent to the server
  * Don't report errors for citations with macro arguments
  * Fix parsing `\label` with options (for example, when using `cleverref`)
  * Fix detecting project root if the home directory contains a `.latexmkrc` file
  * Improve support for handling `Tectonic.toml` projects
  * Cache results of project detection to improve performance
  * Triggering completion inside `\label{...}` will suggest undefined labels
  * Add snippets for `\( ... \)`, `\[ ... \]` and `\{ ... \}`
  * Don't return document symbol with empty name if `\item[]` is encountered
  * Fix extracting label numbers inside theorems defined by `ntheorem` package
  * Fix clearing stale diagnostics reported by the server
  * Speed up reading bibliographies with many string definitions
  * Add experimental `texlab.experimental.labelReferenceCommands` setting to customize the list of `\ref`-like commands
  * Don't report diagnostics for files that are part of the TeX distro
  * When `workspace/didChangeConfiguration` contains the configuration of multiple LSP servers, `texlab` will try
    to extract the `texlab` configuration instead of falling back to the default settings
  * Keep filtering completion lists server-side if prefix matcher is set
  * Allow brackets and parentheses in label names and similar constructs
* Thu Feb 15 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update specfile:
  * replace rust+cargo with cargo
- Update to version 5.12.3:
  * Fix completing includes in conjunction with \graphicspath
* Sun Jan 21 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 5.12.2:
  * Fix parsing commands when they are used with subscript
  * Don't append a newline each time a BibTeX document is being formatted
  * Avoid trying to parse most of the TeX distro when building the dependency
    graph. Add `texlab.experimental.followPackageLinks` setting to allow
    re-enabling the old behavior
* Wed Dec 13 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 5.12.0:
  * Infer `texlab.build.auxDirectory`, `texlab.build.logDirectory` and
    `texlab.build.pdfDirectory` from `latexmkrc` if available
  * Do not report `undefined reference` errors when using `\nocite{*}`
  * Fix potential crash when parsing build log files
  * Set the final tab stop of the `\begin` snippet inside the environment
- Remove cargo_config since vendored tarball includes it now
* Wed Nov 29 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.11.0:
  * Add texlab.inlayHints.labelDefinitions and
    texlab.inlayHints.labelReferences options
    (gh#latex-lsp/texlab#753)
  * Display inlay hints for label references by default
    (gh#latex-lsp/texlab#753)
  * Moving the build logs to the recycle bin will now clear the
    diagnostics (gh#latex-lsp/texlab-vscode#825)
  * Fix false positive when reporting syntax errors for BibTeX
    accents (gh#latex-lsp/texlab#945)
- Update rust+cargo required version to 1.70.0.
* Mon Oct  2 2023 Olivier Belleux <o.g.m.belleux@gmail.com>
- Remove lines in spec files due "failed to build"
  * # They deleted it.
  install -Dm644 texlab.1 -t %%%%{buildroot}%%%%{_mandir}/man1/
  * %%{_mandir}/man1/texlab.1%%{?ext_man}
* Sun Oct  1 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 5.10.0:
  * Allow passing additional arguments to ChkTeX using texlab.chktex.additionalArgs
  * Fix loading bibliographies from kpathsea search path
  * Don't report duplicate results when using goto definition on includes
  * Fix project detection when there exist files with the same name
  * Do not report parse errors with $ in paths
* Mon Aug 21 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 5.9.2:
  * Don't crash when using comments inside \include-like command
  * Folding ranges include only the contents instead of the entire range of the structure.
    For example, the folding range of an environment will start after the \begin and stop before the \end
* Sun Aug 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Replace obsoleted `disabled` option with `manual`
* Sun Aug 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Reenable cargo test in %%check.
* Sun Aug 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 5.9.1:
  * fixed: improved performance when completing BibTeX entries
  * fixed: don't report unused entries for very large bibliographies
  * fixed: avoid redundant reparses after saving documents
- Changes from before 5.9.1 and after 5.7.0:
  * Use bibliographies found in BIBINPUTS environment variable
  * Add texlab.build.pdfDirectory setting
  * Fix search path for aux files when using \include instead of \input
  * Report diagnostics for unused and undefined labels
  * Report diagnostics for unused BibTeX entries and undefined citations
  * Report diagnostics for duplicate BibTeX entries
  * Report diagnostics for duplicate labels
  * Add texlab.build.auxDirectory and texlab.build.logDirectory settings
  * Deprecate texlab.auxDirectory in favor of texlab.build.auxDirectory
  * Fix parsing paths with |
  * Fix parsing LaTeX identifiers with =
* Sun Jul  9 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Disable checks temporarily until a patched version comes
* Sun Jul  9 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 5.7.0
  * Add symbol support for thmtools
  * Add texlab.findenvironments command to return the list of environments containing a position
  * Show inlay hints for labels after the command instead of inside the argument
  * Prevent adding trailing newline after formating with latexmk
  * Improving `\paragraph` parsing
* Mon May  8 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 5.5.1:
  * Fix spurious completion results when completing environments
  * Fix regression when guessing cursor position after formatting
  * Fix parsing `\verb` command
  * Add `flalign` and `flalign*` to default list of math environments
* Sat Apr 22 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 5.5.0:
  * Allow optionally passing cursor position to textDocument/build request for use in forward search after building.
    Previously, the server had to guess the cursor position
  * Add experimental texlab.experimental.citationCommands setting to allow extending the list of citation commands
  * Add support for escaping placeholders in build arguments similar to forward search
  * Allow configuring completion matching algorithm
  * Fix regression introduced in v5.4.2 involving texlab.cleanArtifacts command.
* Mon Apr 10 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 5.4.1:
  * Do not return symbols with empty names
  * Repair `textDocument/formatting` request
  * From 5.4.0:
  - Add experimental settings to allow extending the list of special environments:
  * `texlab.experimental.mathEnvironments`
  * `texlab.experimental.enumEnvironments`
  * `texlab.experimental.verbatimEnvironments`
  - Add `texlab.changeEnvironment workspace command
  - Add `texlab.showDependencyGraph workspace command
  - Do not show caption or section names in label inlay hints
  - Include more user-defined commands in command completion
  - Parse nested `\iffalse` blocks correctly
  - Parse commands with multi-byte characters correctly
  - Fix checking whether a document can be a root file
* Wed Mar  1 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 5.3.0:
  * Apply percent decoding when searching for PDFs
  * Allow filtering document symbols using regex
  * Return [] instead of "not found" in code action
- Use zstd compression for vendored tarball.
- Restrict to tier 1 rust arches.
* Thu Feb  9 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 5.2.0:
  * * NO CHANGELOG **
* Sat Jan 28 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 5.1.0:
  * Allow manually overriding the root directory using a texlabroot/.texlabroot marker file. See the wiki for more information. (#826, #838)
  * Deprecate texlab.rootDirectory setting in favor of .texlabroot files
  * Do not use .git, .chktexrc, .latexmkrc files/directories to determine the root directory (#826)
  * Fix building documents without an explicit root directory (#837)
- Changes from 5.0.0:
  * BREAKING: texlab.rootDirectory is now used as the folder path from which the compiler is executed relative to the main document. By default it is equal to ".". For more information, please visit the wiki.
  * Improve performance of completion by a huge margin due to a faster filtering method used internally
  * Do not discover project files beyond the provided workspace folders
  * Try to guess the root directory by checking for files such as .latexmkrc or Tectonic.toml if texlab.rootDirectory is not set
  * Update positions of reported build diagnostics when editing the affected line
  * Do not treat links to files as bidirectional by default. This prevents issues where texlab ends up compiling the wrong file in projects with shared files (#806, #757, #679)
  * Fix coverage of directories which need to be watched for changes (#502, #491)
  * Resolve links of the import package correctly
  * Use filterText of completion items when filtering internally (#829)
- Specfile changes:
  * Enable tests
  * Enable `--all-features` flag
* Mon Nov 21 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 4.3.2:
  * Do not try to run the TeX engine on package files and fail the build instead
  * Handle URIs with URL-encoded drive letters on Windows
  * Parse BibTeX entries with unbalanced quotes correctly
  * Provide completion for more acronym commands
  * Fix parsing acronym definitions
* Sun Oct 30 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 4.3.1:
  * Do not crash with a stack overflow when trying to load packages with many internal dependencies
  * Normalize drive letters of all document URIs
  * Fix parsing commands that take file paths as arguments
  * Use the correct working directory and command line arguments when calling `latexindent`
  * Fix publishing to CTAN
* Fri Oct 14 2022 socvirnyl.estela@gmail.com
- Update to version 4.3.0:
  * Bump version to v4.3.0
  * Update dependencies
  * Fix Okular forward search command in docs
  * Bump url from 2.2.2 to 2.3.1 (#755)
  * Bump criterion from 0.3.6 to 0.4.0 (#758)
  * Bump clap from 3.2.20 to 3.2.21 (#759)
  * Only compute inlay hints for the specified range
  * Add test case for inlay hints
  * Provide inlay hints for \label command
  * Add diagnostics test case for URIs with spaces
  * Bump anyhow from 1.0.62 to 1.0.64 (#748)
  * Bump titlecase from 2.1.0 to 2.2.0 (#750)
  * Bump once_cell from 1.13.1 to 1.14.0 (#751)
  * feat(build_log): add column field to BuildError
  * feat(build_log): parse error hint
  * Pass codecov token explicitly to GitHub actions
  * Add env_logger to help debug integration tests
  * Bump insta from 1.19.0 to 1.19.1 (#746)
  * Bump dashmap from 5.3.4 to 5.4.0 (#744)
  * Bump clap from 3.2.17 to 3.2.20 (#747)
  * Bump titlecase from 2.0.0 to 2.1.0 (#742)
  * Bump notify from 5.0.0-pre.16 to 5.0.0 (#743)
  * Prefer matching groups rather than envs in parser
* Sun Sep  4 2022 socvirnyl.estela@gmail.com
- Update to version 4.2.2:
  * Bump serde from 1.0.143 to 1.0.144
  * Bump insta from 1.18.2 to 1.19.0 (#734)
  * Bump serde_json from 1.0.83 to 1.0.85 (#733)
  * Bump lsp-types from 0.93.0 to 0.93.1 (#736)
  * Do not watch the same directory multiple times
  * Bump insta from 1.17.1 to 1.18.2
  * Remove unused Cargo features
  * Bump chrono from 0.4.20 to 0.4.22 (#728)
  * Bump notify from 5.0.0-pre.15 to 5.0.0-pre.16 (#727)
  * Bump serde from 1.0.142 to 1.0.143 (#722)
  * Bump once_cell from 1.13.0 to 1.13.1 (#731)
  * Bump clap from 3.2.16 to 3.2.17 (#729)
  * Bump anyhow from 1.0.59 to 1.0.62 (#732)
  * Log the command when executing forward search
  * Do not treat links to packages as bidirectional
  * Fix reloading when the file watcher reports a change (#730)
* Sat Aug 20 2022 socvirnyl.estela@gmail.com
- Update to version 4.2.1:
  * Bump version to v4.2.1
  * Downgrade anyhow due to yanked version
  * Bump chrono from 0.4.20-rc.1 to 0.4.20 (#717)
  * Bump serde_repr from 0.1.8 to 0.1.9 (#714)
  * Bump serde from 1.0.140 to 1.0.142 (#715)
  * Bump clap from 3.2.15 to 3.2.16 (#709)
  * Bump insta from 1.17.0 to 1.17.1 (#710)
  * Bump anyhow from 1.0.58 to 1.0.60 (#713)
  * Bump serde_json from 1.0.82 to 1.0.83 (#716)
  * Update chrono crate
  * Update changelog
  * Copy both ".chktexrc" and "chktexrc" to temp dir
  * Test for less targets in CI
  * Create file watcher on main thread
  * Run "cargo update"
  * Bump clap from 3.2.14 to 3.2.15 (#698)
  * Bump human_name from 1.3.2 to 1.3.4 (#703)
  * Bump insta from 1.16.0 to 1.17.0 (#706)
  * Use chktexrc directory if found when linting
  * Always use server-side file watching
  * Use current dir as fallback watch location
  * Only trigger dependabot for direct dependencies
  * Fix parsing options when some values are missing
  * Re-add auxiliary directory to watch list
  * Use notify for file watching if no client support
  * Fix working directory of ChkTeX
  * Update dependencies using "cargo update"
  * Bump regex from 1.5.6 to 1.6.0 (#668)
  * Bump criterion-plot from 0.4.4 to 0.4.5 (#681)
  * Bump human_name from 1.0.3 to 1.0.5 (#682)
  * Bump rowan from 0.15.5 to 0.15.6 (#675)
  * Bump plotters from 0.3.1 to 0.3.2 (#672)
  * Bump clap from 3.2.8 to 3.2.12 (#680)
  * Bump ucd-trie from 0.1.3 to 0.1.4 (#670)
  * Bump regex-syntax from 0.6.26 to 0.6.27 (#671)
  * Bump plotters-backend from 0.3.2 to 0.3.4 (#673)
  * Bump criterion from 0.3.5 to 0.3.6 (#674)
  * Bump serde_yaml from 0.8.24 to 0.8.25 (#676)
  * Bump hashbrown from 0.12.1 to 0.12.2 (#677)
  * Bump serde from 1.0.138 to 1.0.139 (#678)
  * Bump once_cell from 1.12.0 to 1.13.0 (#667)
  * Generate CTAN documentation in CI
  * Bump dashmap from 5.2.0 to 5.3.4 (#638)
  * Bump fixedbitset from 0.4.1 to 0.4.2 (#666)
  * Always enable completion feature
  * Bump MSRV to 1.59
  * Remove dead code
  * Compile documentation required by CTAN in CI
  * Do not attempt to install gtar on macOS runner
* Fri Jul 15 2022 socvirnyl.estela@gmail.com
- Update to version 4.2.0:
  * Fix compression tasks
  * Fix release build job name
  * Update transitive dependencies with dependabot
  * Update transitive dependencies
  * Remove multimap dependency
  * Bump serde_json from 1.0.81 to 1.0.82 (#664)
  * Bump clap from 3.2.6 to 3.2.8 (#665)
  * Revert "Re-introduce brunch for benchmarking"
  * Re-introduce brunch for benchmarking
* Sun Jun 19 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- removing cargo tests. not useful
* Sun Jun 19 2022 socvirnyl.estela@gmail.com
- Update to version 4.1.0:
  * Bump version to v4.1.0
  * Fix crates.io deployment job
  * Enable incremental compilation for release builds
  * Add missing env variables to deploy workflow
  * Revert "Switch to glassbench instead of criterion"
  * Improve the heuristic for finding artifacts
  * Use thin LTO for release builds
  * Remove unused dev dependencies
  * Switch to glassbench instead of criterion
  * Bump uuid from 1.1.0 to 1.1.2 (#646)
* Wed Jun  1 2022 socvirnyl.estela@gmail.com
- Update to version 4.0.0:
  * Bump version to v4.0.0
  * Add missing Cargo metadata
  * Use custom citation rendering instead of citeproc-rs (#629)
  * Remove reference to im crate
  * Add command line flag to print version
  * Fix deployment workflow
  * Bump crossbeam-utils from 0.8.6 to 0.8.8
  * Remove Clippy CI job
  * Bump unindent from 0.1.8 to 0.1.9 (#626)
  * Bump log from 0.4.16 to 0.4.17 (#624)
* Sat Mar 12 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial working spec of texlab (3.3.2)
